==> com.liferay.layout.content.page.editor.web-1.0.20.jar: META-INF/resources/js/components/fragment_entry_link/ColumnOverlayGrid.es.js <==
"use strict";

Liferay.Loader.define("layout-content-page-editor-web@1.0.20/js/components/fragment_entry_link/ColumnOverlayGrid.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', '../common/FragmentsEditorShim.es', './ColumnOverlayGrid.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.default = exports.ColumnOverlayGrid = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  require("../common/FragmentsEditorShim.es");

  var _ColumnOverlayGrid = _interopRequireDefault(require("./ColumnOverlayGrid.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { default: obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * ColumnOverlayGrid
   */
  var ColumnOverlayGrid =
  /*#__PURE__*/
  function (_Component) {
    _inherits(ColumnOverlayGrid, _Component);

    function ColumnOverlayGrid() {
      _classCallCheck(this, ColumnOverlayGrid);

      return _possibleConstructorReturn(this, _getPrototypeOf(ColumnOverlayGrid).apply(this, arguments));
    }

    return ColumnOverlayGrid;
  }(_metalComponent.default);

  exports.ColumnOverlayGrid = ColumnOverlayGrid;

  _metalSoy.default.register(ColumnOverlayGrid, _ColumnOverlayGrid.default);

  var _default = ColumnOverlayGrid;
  exports.default = _default;
  //# sourceMappingURL=ColumnOverlayGrid.es.js.map
});
//# sourceMappingURL=ColumnOverlayGrid.es.js.map

==> com.liferay.layout.content.page.editor.web-1.0.52.jar: META-INF/resources/js/components/fragment_entry_link/ColumnOverlayGrid.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.52/js/components/fragment_entry_link/ColumnOverlayGrid.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', '../common/FragmentsEditorShim.es', './ColumnOverlayGrid.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.ColumnOverlayGrid = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  require("../common/FragmentsEditorShim.es");

  var _ColumnOverlayGrid = _interopRequireDefault(require("./ColumnOverlayGrid.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * ColumnOverlayGrid
   */
  var ColumnOverlayGrid =
  /*#__PURE__*/
  function (_Component) {
    _inherits(ColumnOverlayGrid, _Component);

    function ColumnOverlayGrid() {
      _classCallCheck(this, ColumnOverlayGrid);

      return _possibleConstructorReturn(this, _getPrototypeOf(ColumnOverlayGrid).apply(this, arguments));
    }

    return ColumnOverlayGrid;
  }(_metalComponent["default"]);

  exports.ColumnOverlayGrid = ColumnOverlayGrid;

  _metalSoy["default"].register(ColumnOverlayGrid, _ColumnOverlayGrid["default"]);

  var _default = ColumnOverlayGrid;
  exports["default"] = _default;
  //# sourceMappingURL=ColumnOverlayGrid.es.js.map
});
//# sourceMappingURL=ColumnOverlayGrid.es.js.map
